import DefaultLayout from '@/layouts/DefaultLayout/DefaultLayout'
import React from 'react'
import { NextSeo } from 'next-seo'
import Resume from '@/components/Resume/Resume'
import { fetchCV } from '@/services/content-service'
import { FailedFetchCVError } from '@/errors'

export const Title = 'CV'

export async function getServerSideProps () {
  const res = await fetchCV([])

  if (!res.ok) {
    throw new FailedFetchCVError(await res.text())
  }

  const cv = (await res.json()).data
  if (!cv) {
    return {
      notFound: true
    }
  }

  const { competencies, education, languages, certifications, experience } = cv

  return {
    props: {
      competencies,
      education,
      languages,
      certifications,
      experience
    }
  }
}

export default function ResumePage ({
  competencies,
  education,
  certifications,
  languages,
  experience
}) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title} openGraph={
          {
            title: Title
          }
        }
      />
      <h1>{Title}</h1>
      <section>
        <Resume
          competencies={competencies}
          education={education}
          certifications={certifications}
          languages={languages}
          experience={experience}
        />
      </section>
    </DefaultLayout>
  )
}
