import showdown from 'showdown'
import camelcaseKeys from 'camelcase-keys'

const baseUrl = process.env.NEXT_PUBLIC_CONTENT_API_BASE_URL

// @ts-ignore
export const fetchPosts = async (...args) => fetchItems('post', ...args)
export const fetchBookReviews = async (...args) => fetchItems('book_review', ...args)
export const fetchBasicPages = async (...args) => fetchItems('basic_pages', ...args)
export const fetchCV = async (...args) => fetchItems('cv', ...args)

const originalFetch = globalThis.fetch

globalThis.fetch = async (...args) => {
  const response = await originalFetch(...args)

  const originalJson = response.json

  response.json = async function () {
    const data = await originalJson.call(this)
    return camelcaseKeys(data, { deep: true })
  }

  return response
}

export async function fetchItems (type, fields = undefined, filter = undefined) {
  const url = new URL(`${baseUrl}/items/${type}`)

  if (fields?.length) {
    url.searchParams.append('fields', fields.join(','))
  }

  if (filter) {
    url.searchParams.append(
      'filter',
      JSON.stringify(filter)
    )
  }

  return await apiFetch(url.toString())
}

export function getTagsFromPosts (posts) {
  const allTags = {}

  for (const post of posts) {
    if (!post.tags) { continue }

    for (const tag of post.tags) {
      allTags[tag] = !allTags[tag] ? 1 : allTags[tag] + 1
    }
  }

  return allTags
}

export function markdownToHtml (content) {
  const converter = new showdown.Converter({
    tables: true,
    tablesHeaderId: true
  })
  const html = converter.makeHtml(content)
  return html
}

async function apiFetch (...args) {
  // @ts-ignore
  const res = await fetch(...args)
  return res
}
